/*
*	This module takes care of gathering, cleaning, and transforming our data :)
*/

export async function prepareData(endpoint, query){
  //Load the data and return a promise which resolves with said data
	let data = await loadData(endpoint, query)
  // console.log("rawData: ", data)
	data = data.map(cleanData)
  // console.log("cleanedData: ", data)
	data = transformData(data)
  // console.log("transformedData: ", data)
  return data
}

//Load the data and return a promise which resolves with said data
function loadData(url, query){
  return d3.json(url +"?query="+ encodeURIComponent(query) + "&format=json")
    .then(data => data.results.bindings)
}

//Nest the data per country
function transformData(source){
  let transformed =  d3.nest()
		.key(function(d) { return d.landLabel; })
		.entries(source);
  transformed.forEach(country => {
    country.amount = country.values.length
  })
  return transformed
}

//This function gets the nested value out of the object in each property
// in our data
function cleanData(row){
   let result = {}
    Object.entries(row)
    	.forEach(([key, propValue]) => { 		
				result[key] = propValue.value
  	})
   return result
}